@@ -35,22 +35,57 @@ extern int debug;
 
 #include "locatestring.h"
 
+/*
+
+String locator: usage and memory status
+
+        'v': result pointer
+ 
+string = "ABC XYZ XYZ ABC"
+
+pointer = locatestring(string, "XYZ", MATCH_FIRST);
+             v
+        "ABC XYZ XYZ ABC"
+
+pointer = locatestring(string, "XYZ", MATCH_LAST);
+                 v
+        "ABC XYZ XYZ ABC"
+
+pointer = locatestring(string, "XYZ", MATCH_AT_FIRST);
+
+        "ABC XYZ XYZ ABC" (nothing pointed)
+
+pointer = locatestring(string, "ABC", MATCH_AT_FIRST);
+            v
+        "ABC XYZ XYZ ABC" (point the following character)
+
+pointer = locatestring(string, "ABC", MATCH_AT_LAST);
+                     v
+        "ABC XYZ XYZ ABC"
+
+pointer = locatestring(string, "ABC XYZ XYZ ABC", MATCH_COMPLETE);
+         v
+        "ABC XYZ XYZ ABC"
+
+pointer = locatestring(string, "xyZ", MATCH_FIRST|IGNORE_CASE);
+             v
+        "ABC XYZ XYZ ABC"
+
+ */
+
 /*
  * strincmp: strncmp with ignoring case.
  *
  *	Interface is same with strncmp.
  */
 static int
-strincmp(string, pattern, len)
-	const char *string;
-	const char *pattern;
-	size_t len;
+strincmp(const char *string, const char *pattern, size_t len)
 {
 	unsigned char s, p;
 
 	while (len--) {
-		s = tolower(*string++);
-		p = tolower(*pattern++);
+		s = tolower((unsigned char)*string++);
+		p = tolower((unsigned char)*pattern++);
 		if (s != p)
 			return s - p;
 		if (s == 0)
@@ -77,19 +112,14 @@ strincmp(string, pattern, len)
  *
  * This function is made to avoid compatibility problems.
  */
-int	(*cmpfunc)(char *, char*, int);
-
 char *
-locatestring(string, pattern, flag)
-	const char *string;
-	const char *pattern;
-	int flag;
+locatestring(const char *string, const char *pattern, int flag)
 {
 	int c = *pattern;
 	int plen = strlen(pattern);
 	const char *p = NULL;
 	int slen;
-	int (*cmpfunc) ();
+	int (*cmpfunc) (const char *, const char*, size_t);
 #ifdef DEBUG
 	FILE *dbg = stderr;
 	const char *pre = string;
