@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005 Tama Communications Corporation
+ * Copyright (c) 2005, 2006 Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
  *
@@ -29,7 +29,7 @@
 #include "die.h"
 #include "strhash.h"
 #include "hash-string.h"
-#include "obstack.h"
+#include "pool.h"
 
 /*
 
@@ -49,7 +49,7 @@ entry = strhash_assign(hash, "name1", 1);	// allocate entry for the name.
 						+-------------+
 // strhash_xxx() doesn't affect entry->value. So, you can use it freely.
 
-entry->value = strdup("NAME1");
+entry->value = strhash_strdup("NAME1");
 						entry
 						+-------------+
 						|name: "name1"|
@@ -84,14 +84,15 @@ strhash_close(hash);				// free resources.
 STRHASH *
 strhash_open(int buckets)
 {
-	STRHASH *sh = (STRHASH *)check_malloc(sizeof(STRHASH));
+	STRHASH *sh = (STRHASH *)check_calloc(sizeof(STRHASH), 1);
 	int i;
 
-	sh->htab = (struct sh_head *)check_malloc(sizeof(struct sh_head) * buckets);
+	sh->htab = (struct sh_head *)check_calloc(sizeof(struct sh_head), buckets);
 	for (i = 0; i < buckets; i++)
 		SLIST_INIT(&sh->htab[i]);
 	sh->buckets = buckets;
-	obstack_init(&sh->pool);
+	sh->pool = pool_open();
+	sh->entries = 0;
 	return sh;
 }
 /*
@@ -122,10 +123,11 @@ strhash_assign(STRHASH *sh, const char *name, int force)
 	 * If not found, allocate an entry.
 	 */
 	if (entry == NULL && force) {
-		entry = obstack_alloc(&sh->pool, sizeof(struct sh_entry));
-		entry->name = obstack_copy0(&sh->pool, name, strlen(name));
+		entry = pool_malloc(sh->pool, sizeof(struct sh_entry));
+		entry->name = pool_strdup(sh->pool, name, 0);
 		entry->value = NULL;
 		SLIST_INSERT_HEAD(head, entry, ptr);
+		sh->entries++;
 	}
 	return entry;
 }
@@ -141,9 +143,7 @@ strhash_assign(STRHASH *sh, const char *name, int force)
 char *
 strhash_strdup(STRHASH *sh, const char *string, int size)
 {
-	if (size == 0)
-		size = strlen(string);
-	return obstack_copy0(&sh->pool, string, size);
+	return pool_strdup(sh->pool, string, size);
 }
 /*
  * strhash_first: get first entry
@@ -196,8 +196,11 @@ strhash_reset(STRHASH *sh)
 	for (i = 0; i < sh->buckets; i++) {
 		SLIST_INIT(&sh->htab[i]);
 	}
-	obstack_free(&sh->pool, NULL);
-	obstack_init(&sh->pool);
+	/*
+	 * Free all memory in sh->pool but leave it valid for further allocation.
+	 */
+	pool_reset(sh->pool);
+	sh->entries = 0;
 }
 /*
  * strhash_close: close hash array.
@@ -207,7 +210,7 @@ strhash_reset(STRHASH *sh)
 void
 strhash_close(STRHASH *sh)
 {
-	obstack_free(&sh->pool, NULL);
+	pool_close(sh->pool);
 	free(sh->htab);
 	free(sh);
 }
